@@ -1,9 +1,9 @@
 package HTTP::Server::EV::BufTie;
-our $VERSION = '0.21';
+our $VERSION = '0.3';
 use Carp;
 use strict;
 use bytes;
-
+use Guard;
 
 =head1 NAME
 
@@ -26,24 +26,31 @@ It`s possible to support attaching different sockets to different handles in sam
 our %storage;
 
 
+sub new {
+	unless(tied *{$_[1]}){
+		tie *{$_[1]} , __PACKAGE__;
+	}
+	
+	my $coro = $Coro::current;
+	$storage{$coro} = $_[2];
+	
+	Guard::guard {
+		delete $storage{$coro};
+	}
+}
+
 
 sub TIEHANDLE { # pkgname, handle, buffer obj
 	$storage{$Coro::current} = $_[1];
-	bless \my($tmp) , $_[0];
+	bless \%storage , $_[0];
 }
 
 *TIESCALAR=\&TIEHANDLE;
 
 
-sub PRINT {
-	shift;
-	$storage{$Coro::current}->PRINT(@_);
-}
+sub PRINT { shift->{$Coro::current}->PRINT(@_); }
 
-sub PRINTF {
-    shift;
-	$storage{$Coro::current}->PRINTF( @_);
-}
+sub PRINTF { shift->{$Coro::current}->PRINTF(@_); }
 
 sub READLINE { croak "HTTP::Server::EV::BufTie doesn't support a READLINE method"; }
 
@@ -51,12 +58,12 @@ sub GETC { croak "HTTP::Server::EV::BufTie doesn't support a GETC method"; }
 
 sub READ { croak "HTTP::Server::EV::BufTie doesn't support a READ method"; }
 
-sub WRITE { $storage{$Coro::current}->WRITE(@_); }
+sub WRITE { shift->{$Coro::current}->WRITE(@_); }
 
 
 
 sub DESTROY { 
-	delete $storage{$Coro::current};
+	
 }
 
 *CLOSE = \&DESTROY;
