@@ -9,7 +9,7 @@ use Time::HiRes qw(gettimeofday tv_interval);
 use HTTP::Server::EV::Buffer;
 use HTTP::Server::EV::BufTie;
 
-our $VERSION = '0.21';
+our $VERSION = '0.3';
 
 =head1 NAME
 
@@ -64,7 +64,7 @@ $cgi->{buffer} = L<HTTP::Server::EV::Buffer> object
 
 $cgi->buffer - returns non blocking filehandle tied to L<HTTP::Server::EV::Buffer> object
 
-$cgi->attach(local *STDOUT) - attaches STDOUT to socket makes it non blocking 
+$cgi->attach(*STDOUT) - attaches STDOUT to socket makes it non blocking 
 
 =head1 METHODS
 
@@ -89,7 +89,7 @@ sub new {
 	binmode $fh;
 	
 	$self->{buffer} = HTTP::Server::EV::Buffer->new({ fh => $fh });
-	
+	$self->{stdout_guard} = [];
 	
 	## Parse headers. CGI compatible
 	( $self->{headers}{SCRIPT_NAME}, $self->{headers}{QUERY_STRING} ) =(split /\?/, $self->{headers}{REQUEST_URI});
@@ -148,7 +148,7 @@ sub new {
 
 =head2 $cgi->next
 
-Ends port listener callback processing. Don`t use it somewhere except HTTP::Server::EV port listener callback
+Ends port listener callback processing. Don`t use it somewhere except HTTP::Server::EV port listener callback or set goto label NEXT_REQ: 
 
 =cut
 
@@ -198,7 +198,7 @@ Uses L<HTTP::Server::EV::Buffer> to provide non-blocking output.
 	$server->listen( 8080 , sub {
 		my $cgi = shift;
 		
-		$cgi->attach(local *STDOUT); # attach STDOUT to socket
+		$cgi->attach(*STDOUT); # attach STDOUT to socket
 		
 		$cgi->header; # print http headers
 		
@@ -209,10 +209,10 @@ Uses L<HTTP::Server::EV::Buffer> to provide non-blocking output.
 =cut
 
 
-sub attach(&[$*]) {
+sub attach {
 	croak 'Can`t attach closed socket!' unless $_[0]->{buffer};
 	
-	tie *{$_[1]}, 'HTTP::Server::EV::BufTie', $_[0]->{buffer};
+	push @{$_[0]->{stdout_guard}}, HTTP::Server::EV::BufTie->new($_[1], $_[0]->{buffer});
 }
 
 
@@ -342,7 +342,7 @@ All other args will be converted to headers.
 
 sub header {
 	my ($self,$params)=@_;
-	croak 'Can`t print headers closed socket!' unless $_[0]->{buffer};
+	croak 'Can`t print headers to closed socket!' unless $_[0]->{buffer};
 	
 	my $headers = 'HTTP/1.1 '.($params->{'STATUS'} ? delete($params->{'STATUS'}) : '200 OK')."\r\n";
 	$headers .= 'Server: '.($params->{'Server'} ? delete($params->{'Server'}) : 'Perl HTTP::Server::EV')."\r\n";
